@@ -14,6 +14,7 @@ import (
 	"os"
 	"os/exec"
 	"path/filepath"
+	"time"
 
 	"launchpad.net/goget-ubuntu-touch/sysutils"
 )
@@ -32,9 +33,11 @@ import (
 
 type CoreGrubImage struct {
 	BaseImage
+
+	legacyGrub bool
 }
 
-func NewCoreGrubImage(location string, size int64, rootSize int, hw HardwareDescription, oem OemDescription) *CoreGrubImage {
+func NewCoreGrubImage(location string, size int64, rootSize int, hw HardwareDescription, oem OemDescription, updateGrub bool) *CoreGrubImage {
 	return &CoreGrubImage{
 		BaseImage: BaseImage{
 			location:  location,
@@ -44,6 +47,7 @@ func NewCoreGrubImage(location string, size int64, rootSize int, hw HardwareDesc
 			oem:       oem,
 			partCount: 5,
 		},
+		legacyGrub: updateGrub,
 	}
 }
 
@@ -70,7 +74,7 @@ func (img *CoreGrubImage) Partition() error {
 	}
 
 	parted.addPart(grubLabel, "", fsNone, 4)
-	parted.addPart(bootLabel, bootDir, fsFat32, 64)
+	parted.addPart(bootLabel, bootDir, fsFat32, 128)
 	parted.addPart(systemALabel, systemADir, fsExt4, img.rootSize)
 	parted.addPart(systemBLabel, systemBDir, fsExt4, img.rootSize)
 	parted.addPart(writableLabel, writableDir, fsExt4, -1)
@@ -84,10 +88,12 @@ func (img *CoreGrubImage) Partition() error {
 }
 
 func (img *CoreGrubImage) SetupBoot() error {
-	// destinations
-	bootPath := filepath.Join(img.baseMount, string(bootDir), "EFI", "ubuntu", "grub")
-	if err := img.GenericBootSetup(bootPath); err != nil {
-		return err
+	if !img.legacyGrub {
+		// destinations
+		bootPath := filepath.Join(img.baseMount, string(bootDir), "EFI", "ubuntu", "grub")
+		if err := img.GenericBootSetup(bootPath); err != nil {
+			return err
+		}
 	}
 
 	return img.setupGrub()
@@ -144,6 +150,12 @@ func (img *CoreGrubImage) setupGrub() error {
 		return fmt.Errorf("unable to create %s dir: %s", efiGrubDir, err)
 	}
 
+	// create fw update directory
+	fwDir := filepath.Join(img.System(), "boot", "efi", "EFI", "ubuntu", "fw")
+	if err := os.MkdirAll(fwDir, 0755); err != nil {
+		return fmt.Errorf("unable to create %s dir: %s", fwDir, err)
+	}
+
 	bootGrubDir := filepath.Join(img.System(), "boot", "grub")
 	if err := bindMount(efiGrubDir, bootGrubDir); err != nil {
 		return err
@@ -187,6 +199,37 @@ func (img *CoreGrubImage) setupGrub() error {
 		return err
 	}
 
+	if img.legacyGrub {
+		if err := img.updateGrub(); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func (img *CoreGrubImage) updateGrub() error {
+	// ensure we run not into recordfail issue
+	grubDir := filepath.Join(img.System(), "etc", "default", "grub.d")
+	if err := os.MkdirAll(grubDir, 0755); err != nil {
+		return fmt.Errorf("unable to create %s dir: %s", grubDir, err)
+	}
+	grubFile, err := os.Create(filepath.Join(grubDir, "50-system-image.cfg"))
+	if err != nil {
+		return fmt.Errorf("unable to create %s file: %s", grubFile.Name(), err)
+	}
+	defer grubFile.Close()
+	if _, err := io.WriteString(grubFile, grubCfgContent); err != nil {
+		return err
+	}
+
+	// I don't know why this is needed, I just picked it up from the original implementation
+	time.Sleep(3 * time.Second)
+
+	if out, err := exec.Command("chroot", img.System(), "update-grub").CombinedOutput(); err != nil {
+		return fmt.Errorf("unable to update grub: %s", out)
+	}
+
 	return nil
 }
 
